/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import PropType from 'prop-types';

function DateRenderer({options, value}) {
	if (!value) {
		return null;
	}

	let timestamp = value;

	if (typeof value === 'string') {
		const date = value.split('T')[0];

		const dateArray = date.split('-');

		if (dateArray.length === 3) {
			const [year, month, day] = dateArray;

			timestamp = Date.UTC(Number(year), Number(month) - 1, Number(day));
		}
		else {
			timestamp = Number(value);
		}
	}

	const locale = themeDisplay.getBCP47LanguageId();

	const dateOptions = {
		day: options?.format?.day || 'numeric',
		month: options?.format?.month || 'short',
		timeZone: options?.format?.timeZone || 'UTC',
		year: options?.format?.year || 'numeric',
	};

	const formattedDate = new Intl.DateTimeFormat(locale, dateOptions).format(
		timestamp
	);

	return formattedDate;
}

DateRenderer.propTypes = {
	options: PropType.shape({
		format: PropType.object,
	}),
	value: PropType.string.isRequired,
};

export default DateRenderer;
